<?php

namespace Superrobota\Hardskill\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Hardskill\Models\Craft;

class CraftPolicy
{

    /**
     * Determine if the given user can view the craft.
     *
     * @param UserPolicy $user
     * @param Craft $craft
     *
     * @return bool
     */
    public function view(UserPolicy $user, Craft $craft)
    {
        if ($user->canDo('hardskill.craft.view') && $user->isAdmin()) {
            return true;
        }

        return $craft->user_id == user_id() && $craft->user_type == user_type();
    }

    /**
     * Determine if the given user can create a craft.
     *
     * @param UserPolicy $user
     * @param Craft $craft
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('hardskill.craft.create');
    }

    /**
     * Determine if the given user can update the given craft.
     *
     * @param UserPolicy $user
     * @param Craft $craft
     *
     * @return bool
     */
    public function update(UserPolicy $user, Craft $craft)
    {
        if ($user->canDo('hardskill.craft.edit') && $user->isAdmin()) {
            return true;
        }

        return $craft->user_id == user_id() && $craft->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given craft.
     *
     * @param UserPolicy $user
     * @param Craft $craft
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Craft $craft)
    {
        return $craft->user_id == user_id() && $craft->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given craft.
     *
     * @param UserPolicy $user
     * @param Craft $craft
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Craft $craft)
    {
        if ($user->canDo('hardskill.craft.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given craft.
     *
     * @param UserPolicy $user
     * @param Craft $craft
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Craft $craft)
    {
        if ($user->canDo('hardskill.craft.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
