<?php

namespace Superrobota\Hardskill\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Hardskill\Models\Hardskill;

class HardskillPolicy
{

    /**
     * Determine if the given user can view the hardskill.
     *
     * @param UserPolicy $user
     * @param Hardskill $hardskill
     *
     * @return bool
     */
    public function view(UserPolicy $user, Hardskill $hardskill)
    {
        if ($user->canDo('hardskill.hardskill.view') && $user->isAdmin()) {
            return true;
        }

        return $hardskill->user_id == user_id() && $hardskill->user_type == user_type();
    }

    /**
     * Determine if the given user can create a hardskill.
     *
     * @param UserPolicy $user
     * @param Hardskill $hardskill
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('hardskill.hardskill.create');
    }

    /**
     * Determine if the given user can update the given hardskill.
     *
     * @param UserPolicy $user
     * @param Hardskill $hardskill
     *
     * @return bool
     */
    public function update(UserPolicy $user, Hardskill $hardskill)
    {
        if ($user->canDo('hardskill.hardskill.edit') && $user->isAdmin()) {
            return true;
        }

        return $hardskill->user_id == user_id() && $hardskill->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given hardskill.
     *
     * @param UserPolicy $user
     * @param Hardskill $hardskill
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Hardskill $hardskill)
    {
        return $hardskill->user_id == user_id() && $hardskill->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given hardskill.
     *
     * @param UserPolicy $user
     * @param Hardskill $hardskill
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Hardskill $hardskill)
    {
        if ($user->canDo('hardskill.hardskill.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given hardskill.
     *
     * @param UserPolicy $user
     * @param Hardskill $hardskill
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Hardskill $hardskill)
    {
        if ($user->canDo('hardskill.hardskill.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
