<?php

namespace Superrobota\Hardskill\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Hardskill\Models\Position;

class PositionPolicy
{

    /**
     * Determine if the given user can view the position.
     *
     * @param UserPolicy $user
     * @param Position $position
     *
     * @return bool
     */
    public function view(UserPolicy $user, Position $position)
    {
        if ($user->canDo('hardskill.position.view') && $user->isAdmin()) {
            return true;
        }

        return $position->user_id == user_id() && $position->user_type == user_type();
    }

    /**
     * Determine if the given user can create a position.
     *
     * @param UserPolicy $user
     * @param Position $position
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('hardskill.position.create');
    }

    /**
     * Determine if the given user can update the given position.
     *
     * @param UserPolicy $user
     * @param Position $position
     *
     * @return bool
     */
    public function update(UserPolicy $user, Position $position)
    {
        if ($user->canDo('hardskill.position.edit') && $user->isAdmin()) {
            return true;
        }

        return $position->user_id == user_id() && $position->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given position.
     *
     * @param UserPolicy $user
     * @param Position $position
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Position $position)
    {
        return $position->user_id == user_id() && $position->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given position.
     *
     * @param UserPolicy $user
     * @param Position $position
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Position $position)
    {
        if ($user->canDo('hardskill.position.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given position.
     *
     * @param UserPolicy $user
     * @param Position $position
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Position $position)
    {
        if ($user->canDo('hardskill.position.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
