<?php

namespace Superrobota\Hardskill\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Hardskill\Models\Sector;

class SectorPolicy
{

    /**
     * Determine if the given user can view the sector.
     *
     * @param UserPolicy $user
     * @param Sector $sector
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sector $sector)
    {
        if ($user->canDo('hardskill.sector.view') && $user->isAdmin()) {
            return true;
        }

        return $sector->user_id == user_id() && $sector->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sector.
     *
     * @param UserPolicy $user
     * @param Sector $sector
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('hardskill.sector.create');
    }

    /**
     * Determine if the given user can update the given sector.
     *
     * @param UserPolicy $user
     * @param Sector $sector
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sector $sector)
    {
        if ($user->canDo('hardskill.sector.edit') && $user->isAdmin()) {
            return true;
        }

        return $sector->user_id == user_id() && $sector->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sector.
     *
     * @param UserPolicy $user
     * @param Sector $sector
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sector $sector)
    {
        return $sector->user_id == user_id() && $sector->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sector.
     *
     * @param UserPolicy $user
     * @param Sector $sector
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sector $sector)
    {
        if ($user->canDo('hardskill.sector.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sector.
     *
     * @param UserPolicy $user
     * @param Sector $sector
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sector $sector)
    {
        if ($user->canDo('hardskill.sector.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
